package
Version:
v1.1.3
Opens a new window with list of versions in this module.
Published: Feb 2, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
global 提供了全局数据
此包提供了软件的基础信息
func GetAppInfo() *appInfo
GetAppInfo 获取应用信息
Source Files
¶
Click to show internal directories.
Click to hide internal directories.